function [resid,pi_below,pi_at,pi_above] = foc_residual(z,alpha,cf,lambda,mu,nbar,uz,oz,r,sigma,sunkcost,tau,wage,dum,deriv)
%
% solve for the optimal threshold in the following situation
% dum == 1: no sunk cost, this is just oz
% dum == 2: deterministic case
% dum == 3: stochastic case with a sunk cost
%
% deriv = 1: gives the derivative of the function for newton-raphson

R1  = - ( mu.z + sqrt(mu.z^2 + 2 * (r+lambda) * sigma.z^2) ) / sigma.z^2 ;
pi_below    = exp( z /(1-alpha) ) * (alpha/wage) ^ ( alpha/(1-alpha) ) * ( 1 - alpha ) - cf ;
pi_at       = exp(z) * nbar^alpha - wage*nbar - cf ;
pi_above    = exp( z /(1-alpha) ) * (alpha / ( wage*(1+tau.wage) ) ) ^ ( alpha/(1-alpha) ) * ( 1 - alpha ) - cf*(1+tau.cf) ;
%
if deriv 
  
  if dum == 1
      resid           = -exp(z) * (nbar^alpha) + exp(z/(1 - alpha))*(alpha/((1 + tau.wage)*wage))^(alpha/(1 - alpha)) ;
    else
      if dum == 2
        % irrelevant for now but TO BE WRITTEN
      else
         resid_sto   = ( (-1 + alpha)*exp(z/(1 - alpha))*R1 ...
                    *( 1 + (-1 + alpha)*exp( (z-oz)*(1+(-1+alpha)*R1)/(-1 +alpha))*R1) ...
                    *(alpha/(wage + tau.wage*wage))^(alpha/(1 - alpha)) ) ...
                    /(1 + (-1 + alpha)*R1) ...
                    + ( exp(-oz*R1)*( (nbar^alpha)*R1*(-exp(z + oz*R1) + exp(oz+z*R1)*R1) ...
                    + exp(z*R1)*(-1+R1)*R1*(cf*tau.cf - nbar*wage)))/(-1 + R1) ;
          resid        = resid_sto ;    
      end
  end
  
  else
    if dum == 1
      resid_nosunk    = pi_above - pi_at ;
      resid           = resid_nosunk ;
    else
      if dum == 2
        resid_det   = pi_above - pi_at - (r+lambda)*sunkcost ;
        resid       = resid_det ;
        else
          resid_sto   = -R1 * exp(z* R1) * ...
                        ( ( exp(z-z*R1)-exp(oz-oz*R1) ) * nbar^alpha / (-1+R1)...
                        + cf * tau.cf * ( exp(-z*R1)- exp(-oz*R1) ) / R1 ...
                        - ( exp(-z * R1) - exp(-oz * R1) ) * nbar * wage / R1 ...
                        - (-1+alpha)^2 * exp( (z+oz) * (1+(-1+alpha) * R1) /(1-alpha) ) ...
                        * ( exp( z * (1+(-1+alpha) * R1) / (-1+alpha) ) ...
                        - exp( oz * (1+(-1+alpha) * R1) /(-1+alpha)) ) ...
                        * ( alpha / ( wage + tau.wage * wage) )^(alpha/(1-alpha)) ...
                        /(1+(-1+alpha) * R1) ) ...
                        - (r+lambda)*sunkcost ;                    
          resid       = resid_sto ;
          
          end
    end
end
%