
clear all ; close all ; clc ;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% this program generates a panel from the model,      %
% and alculate some moments                           %
%                                                     %
% the model panel is obtained by starting from the    %
% invariant distribution, which is in closed form,    %
% and simulating from then on.                        %
% note that the # of firms simulated matters for some %
% moments                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% parameter values:
AS = [0.0301	0.0030	0.0520	0.0211	1.0281	0.0004
    0.0293	0.0029	0.0527	0.0134	1.2908	0
    0.0302	0.0032	0.0504	0.0324	0	0.0015
    0.0301	0.0030	0.0520	0.0211	0 0 ];
%     0.0296	0.0013	0.0230	0.0177	0.4516	0.0001
%     0.0300	0.0044	0.0766	0.0210	1.4634	0.0004
%     0.0211	0.0020	0.0416	0.0218	0.9021	0.0004
%     0.0230	0.0011	0.0291	0.0148	0.6059	0.0001
%     0.0276	0.0025	0.0480	0.0270	0.9475	0.0008
%     0.0226	0.0015	0.0370	0.0483	0.8959	0.0002] ;

ALPHAvec = [0.66,0.66,0.66,0.66,0.85,0.50,0.69,0.78,0.66,0.74] ;
paramcompSUNK = AS(:,5) ;
paramcompTAU = AS(:,6) ;
paramcompLAMBDA = AS(:,1) ;
paramcompMU = AS(:,2) ;
paramcompSIGMA = AS(:,3) ;
paramcompMRE = AS(:,4) ;

printeps = 0  ; % set to 1 to get eps files
balpanel = 0  ; % balance the panel (NO now)
r                                   = 0.05 ;
nbar                                = 49.01 ;
wage                                = 1 ;
cf                                  = 1 ;
tau.wage= 0 ; tau.cf = 0 ;sunkcost = 0 ;
z0 = 1.4166 ;                     % starting value: does not matter for our moments as long as starting employt<20. BUT helps with simuls.
sigma.MREy                      = .02 ; % measrement error in output
dt                              = .05 ; % step size in time
T                               = 7*round( 1 / dt ) ; % 7 years are simulated
NNk                             = 1e5 ; % this is too small for estimation. need rather 2e5. but slow in matlab.
N = NNk ;
shocks.n                        = randn(N,T) ; % drawn from a normal distribution -- shocks
s_y                             = sort( rand(N,1) ) ; % drawn from a uniform distribution -- starting distribution


for nummodel=1:4
    
    % to see how long it takes
    disp(nummodel)
    
    
    % simul dimension
    N = NNk ;
    T                               = 7*round( 1 / dt ) ; % 7 years are simulated
    
    % parameters
    alpha                           = ALPHAvec(nummodel) ;
    lambda                          = paramcompLAMBDA(nummodel) ;
    sigma.z                         = paramcompSIGMA(nummodel) ;
    mu.z                            =  paramcompMU(nummodel) ;
    tau.wage                        = paramcompTAU(nummodel) ;
    sunkcost                        = paramcompSUNK(nummodel) ;
    sigma.MRE                       = paramcompMRE(nummodel) ;
    
    
    % solve policy rules:
    [uz,oz,hz,beta1,beta2] = thresholds(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0);
    
    % calculate invariant distribution --
    % write linear system: AA*C = BB
    BB = zeros(5,1) ;
    BB(4) = 1 ;
    %
    AA = zeros(5) ;
    AA(1,1) = exp(beta2*z0) ;
    AA(1,2) = -exp(beta1*z0) ;
    AA(1,3) = -exp(beta2*z0) ;
    %
    AA(2,2) = exp(beta1*hz) ;
    AA(2,3) = exp(beta2*hz) ;
    %
    AA(3,4) = exp(beta2*hz) ;
    AA(3,5) = -exp(beta1*hz) ;
    %
    AA(4,1) = 1/beta2*exp(beta2*z0) ;
    AA(4,2) = 1/beta1*(exp(beta1*hz)-exp(beta1*z0)) ;
    AA(4,3) = 1/beta2*(exp(beta2*hz)-exp(beta2*z0)) ;
    AA(4,4) = 1/beta2*exp(beta2*hz) ;
    AA(4,5) = -1/beta1*exp(beta1*hz) ;
    %
    AA(5,4) = lambda*1/beta2*exp(beta2*hz) ;
    AA(5,5) = -lambda*1/beta1*exp(beta1*hz) ;
    AA(5,2) =  sigma.z^2/2*(beta1*exp(beta1*hz)) ;
    AA(5,3) =  sigma.z^2/2*(beta2*exp(beta2*hz)) ;
    %
    sol = inv(AA)*BB ;
    %
    C1 = sol(1) ;
    C2 = sol(2) ;
    C3 = sol(3) ;
    C4 = sol(4) ;
    C5 = sol(5) ;
    
    cdf_below_athz = 1-exp(beta1*(hz-z0)) ;
    cdf_below_atz0 = C1*exp(beta2*z0)/beta2 ;
    
    y0                              = C1 * exp( beta2 * z0 ) / beta2 ;
    hy                              = C4 * exp( beta2 * hz ) / beta2 ;
    y_before_belowz0                = s_y( s_y<y0 ) ; % z before and below z0
    y_before_abovez0                = s_y( (s_y>=y0)&(s_y<cdf_below_athz) ) ; % z before and above z0
    y_after_belowhz                 = s_y( (s_y>=cdf_below_athz)&(s_y<hy+cdf_below_athz) ) - cdf_below_athz ; % z after and below hz
    y_after_abovehz                 = s_y( s_y>=hy+cdf_below_athz ) - cdf_below_athz ;% z after and above hz
    
    z_before_belowz0                = log( beta2 * y_before_belowz0 / C1 ) / beta2 ;
    z_after_belowhz                 = log( beta2 * y_after_belowhz / C4 ) / beta2 ;
    z_after_abovehz                 = log( -beta1 * C4 * exp ( beta2 * hz ) / ( beta2* C5) ...
        + beta1 * y_after_abovehz / C5 + exp( beta1 * hz ) ) / beta1 ;
    resid                           = @(z,y) ( (1 - exp( -z0*beta1 + hz*(beta1-beta2) + z*beta2) ) * beta1 + ( -1 + exp( (z-z0)*beta1 ) ) * beta2 ) / ( beta1 - beta2 ) - y ;
    
    %%% to speed up calculation : interpolate decision rules
    z_before_abovez0 = [] ;
    
    if length(y_before_abovez0)>1
        NN = 2000 ;
        xxs1 = linspace(min(y_before_abovez0),max(y_before_abovez0)*.85,NN/4) ;
        xxs2 = linspace(max(y_before_abovez0)*.85+1e-12,max(y_before_abovez0)*.99,NN/4) ;
        xxs3 = linspace(max(y_before_abovez0)*.99+1e-12,max(y_before_abovez0),NN/2) ;
        xxs = [xxs1,xxs2,xxs3] ;
        gs = zeros(NN,1);
        gs(1)            = fzero( @(z) resid(z,xxs(1)),[z0,hz]) ;
        for in=2:NN;
            gs(in)        = fzero( @(z) resid(z,xxs(in)),[gs(in-1)*.99 hz]) ;
        end
        z_before_abovez0 = interp1(xxs,gs,y_before_abovez0);%,'spline') ;
    end
    
    n_before_belowz0                = exp( z_before_belowz0 / (1-alpha) ) * ( alpha / wage ) ^ ( 1 / ( 1 - alpha ) ) .* ( z_before_belowz0 < uz) ...
        + nbar .* ( z_before_belowz0 >=uz ) ;
    n_before_abovez0                = exp( z_before_abovez0 / (1-alpha) ) * ( alpha / wage ) ^ ( 1 / ( 1 - alpha ) ) .* ( z_before_abovez0 < uz) ...
        + nbar .* ( z_before_abovez0 >=uz ) ;
    n_after_belowhz                 = exp( z_after_belowhz / (1-alpha) ) * ( alpha / wage ) ^ ( 1 / ( 1 - alpha ) ) .* ( z_after_belowhz < uz) ...
        + nbar .* ( z_after_belowhz >=uz ) .* ( z_after_belowhz < oz ) ...
        + exp( z_after_belowhz / (1-alpha) ) * ( alpha / ( wage  * ( 1 + tau.wage ) ) ) ^ ( 1 / ( 1 - alpha ) ) ...
        .* ( z_after_belowhz >= oz ) ;
    n_after_abovehz                 = exp( z_after_abovehz / (1-alpha) ) * ( alpha / wage ) ^ ( 1 / ( 1 - alpha ) ) .* ( z_after_abovehz < uz) ...
        + nbar .* ( z_after_abovehz >=uz ) .* ( z_after_abovehz < oz ) ...
        + exp( z_after_abovehz / (1-alpha) ) * ( alpha / ( wage  * ( 1 + tau.wage ) ) ) ^ ( 1 / ( 1 - alpha ) ) ...
        .* ( z_after_abovehz >= oz ) ;
    
    zstart                               = [z_before_belowz0;z_before_abovez0;z_after_belowhz;z_after_abovehz] ;
    [nbefore,aa]                         = size([z_before_abovez0;z_before_belowz0]) ;
    sstart                               = [zeros(nbefore,1);ones(N-nbefore,1)] ;
    nstart                               = [n_before_belowz0;n_before_abovez0;n_after_belowhz;n_after_abovehz] ;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % now dynamic simulation
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    d_exit      = rand(N,T) < lambda * dt ;
    d_stay      = ones(N,T) - d_exit ;
    
    zsim         = zeros(N,T) ;
    zsim(:,1)    = zstart ;
    ssim         = sstart ;
    id = zeros(N,T) ; % keep track if this is the same firm or a new one.
    
    for t=2:T
        zsim(:,t) = zsim(:,t-1) + mu.z * dt + sigma.z * sqrt(dt) * shocks.n(:,t) ;
        ssim(:,t) = max( ssim(:,t-1) , zsim(:,t) > hz ) ;
        U = find(d_exit(:,t)==1) ;
        zsim(U,t) = z0 ;
        ssim(U,t) = 0 ;
        id(U,t) = id(U,t-1) + 1 ;
        id(:,t) = max(id(:,t),id(:,t-1)) ;
    end
    
    nsim        = ( ssim == 0 ) .* (  ( zsim < uz ) .* exp( zsim / (1-alpha) ) * ( alpha / wage  ) ^ ( 1 / ( 1 - alpha ) ) ...
        + ( zsim >= uz ) .* nbar ) ...
        + ( ssim == 1 ) .* (  ( zsim < uz ) .* exp( zsim / (1-alpha) ) * ( alpha / wage  ) ^ ( 1 / ( 1 - alpha ) ) ...
        + ( zsim >= uz ) .* ( zsim < oz ) .* nbar  ...
        + ( zsim >= oz ) .* exp( zsim / (1-alpha) ...
        ) * ( alpha / ( wage * ( 1 + tau.wage ) ) ) ^ ( 1 / ( 1 - alpha ) ) )  ;
    
    %%%%%%%%%%%%%%%%%%%%%
    % Measurement Error %
    %%%%%%%%%%%%%%%%%%%%%
    
    MREsim = -.5*(sigma.MRE)^2 + sigma.MRE*randn(N,T) ;
    nsimME = nsim.*exp(MREsim) ;
    
    MREsimy = -.5*(sigma.MREy)^2 + sigma.MREy*randn(N,T) ;
    
    %%% interpretation of N MRE as measurement error, not transitory shock:
    ysim = exp( zsim ).*nsim.^(alpha) ;
    %%% ow this would be exp( zsim ).*nsimME.^(alpha)
    ysimME = ysim.*exp(MREsimy) ;
    
    % round everything:
    nsim = round(nsim) ;
    nsimME = round(nsimME) ;
    
    %%% balance the panel -- not anymore!
    if balpanel==1
        M = find(id(:,T)==0) ;
        nsim = nsim(M,:) ;
        nsimME = nsimME(M,:) ;
        id = id(M,:) ;
        ysim = ysim(M,:) ;
        ysimME = ysimME(M,:) ;
    end
    
    ynsim = ysim./nsim ;
    ynsimMEY = ysimME./nsimME ;
    
    %%% 7 observation:
    one_t = floor(1/dt) ;
    T = T/one_t ;
    id = id(:,1:one_t:end) ;
    nsim = nsim(:,1:one_t:end) ;
    nsimME = nsimME(:,1:one_t:end) ;
    ysim = ysim(:,1:one_t:end) ;
    ysimME = ysimME(:,1:one_t:end) ;
    ynsim = ynsim(:,1:one_t:end) ;
    ynsimMEY = ynsimMEY(:,1:one_t:end) ;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % calculate:
    % 1 size distribution
    % 2 prob of inaction by size
    % 3 lab productivity by size (not here)s
    % 4 std dev of change in n by size
    % 5 skewness of change in n by size
    % 6 size of jump in n if go over the threshold
    % all, w or wo measurement error
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    for isx=1:2 % first do calc without ME, then with ME
        
        if isx==1
            n_calc = nsim ;
        else
            n_calc = nsimME ;
        end
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Simple unconditional mean, median, SD, skewness, kurtosis %
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        dlogN = log(n_calc(:,2:end))-log(n_calc(:,1:end-1)) ;
        JK = ( id(:,2:end)==id(:,1:end-1) ) ; % continuing firms only!
        
        % in the past we also used a 20 threshold in data for n. does not
        % matter for these stats
        Z = (n_calc(:,1:end-1)>=20&JK==1) ; Z = Z(:) ;
        
        
        if isx==1
            simple_mean = mean(dlogN(Z==1)) ;
            simple_median = median(dlogN(Z==1)) ;
            simple_std = std(dlogN(Z==1)) ;
            simple_var = std(dlogN(Z==1))^2 ;
            simple_skew = myskewness(dlogN(Z==1)) ;
            simple_kurt = mykurt(dlogN(Z==1)) ;
        else
            simple_meanME = mean(dlogN(Z==1)) ;
            simple_medianME = median(dlogN(Z==1)) ;
            simple_stdME = std(dlogN(Z==1)) ;
            simple_varME = std(dlogN(Z==1))^2 ;
            simple_skewME = myskewness(dlogN(Z==1)) ;
            simple_kurtME = mykurt(dlogN(Z==1)) ;
        end
        
        %%%%%%%%%%%%%%%%%%%%%
        % size distribution %
        % pooling all periods    %
        %%%%%%%%%%%%%%%%%%%%%
        
        sizedis_x = zeros(100,T) ;
        for T1=1:T;
            for i=1:99
                sizedis_x(i,T1) = length(find(n_calc(:,T1)==i)) ;
            end
            sizedis_x(100,T1) = length(find(n_calc(:,T1)>=100)) ;
        end
        
        
        if isx==1
            sizedis =   sum(sizedis_x,2) ;
        else
            sizedisME = sum(sizedis_x,2);
        end
        
        %%%%%%%%%%%%%%%%%%%%%
        % size distribution %
        % conditional on having been above 50 in the past
        %%%%%%%%%%%%%%%%%%%%%
        
        % Prob(size(i,T)=x | size(i,t)>49 for some t<T) ;
        
        size_cond = zeros(100,T) ;
        size_cond2 = zeros(100,T) ;
        size_cond3 = zeros(100,T) ;
        
        for T2=2:T ;
            Jnew = zeros(N,1) ;
            for u=1:T2-1
                J = (n_calc(:,u)>=55) ;
                Jnew(J) = 1 ;
                J2 = (id(:,u)~=id(:,T2)) ;
                Jnew(J2) = 0 ;
            end
            
            J = find(Jnew==1) ;
            
            J2 = J ; % find(max(n_calc(:,1:T2-1),[],2)>=55) ;
            J3 = J ; % find(max(n_calc(:,1:T2-1),[],2)>=55) ;
            for i=1:99
                size_cond(i,T2) = length(find(n_calc(J,T2)==i)) ; % # of firms of size i among those that were above 55 at some point earlier
                size_cond2(i,T2) = length(find(n_calc(J2,T2)==i)) ;
                size_cond3(i,T2) = length(find(n_calc(J3,T2)==i)) ;
            end
            size_cond(100,T2) = length(find(n_calc(J,T2)>=100)) ;
            size_cond2(100,T2) = length(find(n_calc(J2,T2)>=100)) ;
            size_cond3(100,T2) = length(find(n_calc(J3,T2)>=100)) ;
        end
        
        
        if isx==1
            size_condX = sum(size_cond(:,2:T),2) ;
            size_condX2 = sum(size_cond2(:,2:T),2) ;
            size_condX3 = sum(size_cond3(:,2:T),2) ;
        else
            size_condXME = sum(size_cond(:,2:T),2) ;
            size_condXME2 = sum(size_cond2(:,2:T),2) ;
            size_condXME3 = sum(size_cond3(:,2:T),2) ;
        end
        
        % Y/N: dropped for now.
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % inaction between two consecutive periods
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        sum_inact_x = zeros(100,T) ;
        sum_cases = zeros(100,T) ;
        
        for T1=2:T
            T2 = T1-1 ;
            for i=1:99
                sum_inact_x(i,T1) = length(find(n_calc(:,T2)==i&n_calc(:,T1)==n_calc(:,T2)&id(:,T1)==id(:,T2)));
                sum_cases(i,T1) = length(find(n_calc(:,T2)==i&id(:,T1)==id(:,T2))) ;
            end
            sum_inact_x(100,T1) = length(find(n_calc(:,T2)>=100&n_calc(:,T1)==n_calc(:,T2)&id(:,T1)==id(:,T2)));
            sum_cases(100,T1) = length(find(n_calc(:,T2)>=100&id(:,T1)==id(:,T2))) ;
        end
        
        if isx==1
            probinact = sum(sum_inact_x(:,2:T),2)./sum(sum_cases(:,2:T),2) ;
        else
            probinactME = sum(sum_inact_x(:,2:T),2)./sum(sum_cases(:,2:T),2) ;
        end
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % mean, std dev, skewness and kurtosis by size
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        Nstack = n_calc(:,1:T-1) ;
        Nstack = Nstack(:) ;
        Nfut = n_calc(:,2:T) ;
        Nfut = Nfut(:) ;
        
        idfut = id(:,2:T) ;
        idfut = idfut(:) ;
        
        idstack  = id(:,1:T-1) ;
        idstack = idstack(:) ;
        
        dlogNstack = log(n_calc(:,2:T)) - log(n_calc(:,1:T-1)) ;
        dlogNstack = dlogNstack(:) ;
        JK2 = JK(:) ;
        dlogNstack = dlogNstack(JK2==1) ;
        
        Nstack = Nstack(JK2==1) ;
        Nfut = Nfut(JK2==1) ;
        
        
        mean_x = zeros(100,1) ;
        stddis_x = zeros(100,1) ;
        skew_x = zeros(100,1) ;
        kurt_x = zeros(100,1) ;
        
        for i=1:99
            x1 = find(Nstack==i) ;
            mean_x(i) = mean(dlogNstack(x1)) ;
            stddis_x(i) = std(dlogNstack(x1)) ;
            skew_x(i) = myskewness(dlogNstack(x1)) ;
            kurt_x(i) = mykurt(dlogNstack(x1)) ;
        end
        
        x1 = find(Nstack>=100) ;
        mean_x(100) = mean(dlogNstack(x1)) ;
        stddis_x(100) = std(dlogNstack(x1)) ;
        skew_x(100) = myskewness(dlogNstack(x1)) ;
        kurt_x(100) = mykurt(dlogNstack(x1)) ;
        
        if isx==1
            meandis = mean_x ;
            stddis = stddis_x ;
            skew = skew_x ;
            kurt = kurt_x ;
        else
            meandisME = mean_x ;
            stddisME = stddis_x ;
            skewME = skew_x ;
            kurtME = kurt_x ;
        end
        
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % mean, std dev, skewness and kurtosis by size
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        
        U = find(Nfut>=50&Nstack<50) ;
        sizejump_x = mean(dlogNstack(U)) ;
        
        if isx==1
            sizejump = sizejump_x ;
        else
            sizejumpME = sizejump_x ;
        end
        
    end
    
    
    
    % Store results
    store1(nummodel,:) = sizedis ;
    store1b(nummodel,:) = sizedisME ;
    
    store2(nummodel,:) = size_condX ;
    store2b(nummodel,:) = size_condXME ;
    
    store11(nummodel,:) = size_condX2 ;
    store11b(nummodel,:) = size_condXME2 ;
    
    store111(nummodel,:) = size_condX3 ;
    store111b(nummodel,:) = size_condXME3 ;
    
    store3(nummodel,:) = probinact ;
    store3b(nummodel,:) = probinactME ;
    
    store4(nummodel,:) = stddis ;
    store4b(nummodel,:) = stddisME ;
    
    
    store7(nummodel,:) = sizejump ;
    store7b(nummodel,:) = sizejumpME ;
    
    
    store5(nummodel,:) = skew ;
    store5b(nummodel,:) = skewME ;
    
    store6(nummodel,:) = kurt ;
    store6b(nummodel,:) = kurtME ;
    
    % to add: std dev, conditional on a change
    % transition matrices?
    
    storebasics(nummodel,:) = [simple_mean,simple_median,simple_std,simple_var,simple_skew,simple_kurt] ;
    storebasicsME(nummodel,:) = [simple_meanME,simple_medianME,simple_stdME,simple_varME,simple_skewME,simple_kurtME] ;
    
end





for nummodel=1:4
    A = store1b(nummodel,40:60)' ;
    bins55U(nummodel,:) = [sum(A(1:5)),sum(A(6:10)),sum(A(11:15)),sum(A(16:20))]/sum(A(1:20)) ;
    bins73U(nummodel,:) = [sum(A(1:7))/7,sum(A(8:10))/3,sum(A(11:13))/3,sum(A(14:20))/7]/sum(A(1:20)) ;    
    A = store111b(nummodel,40:60)' ;
    bins55C55(nummodel,:) = [sum(A(1:5)),sum(A(6:10)),sum(A(11:15)),sum(A(16:20))]/sum(A(1:20)) ;
    bins73C55(nummodel,:) = [sum(A(1:7))/7,sum(A(8:10))/3,sum(A(11:13))/3,sum(A(14:20))/7]/sum(A(1:20)) ;
end

% for nummodel=1:4
%     A = store1(nummodel,40:60)' ;
%     bins55U(nummodel,:) = [sum(A(1:5)),sum(A(6:10)),sum(A(11:15)),sum(A(16:20))]/sum(A(1:20)) ;
%     bins73U(nummodel,:) = [sum(A(1:7))/7,sum(A(8:10))/3,sum(A(11:13))/3,sum(A(14:20))/7]/sum(A(1:20)) ;
%     A = store111(nummodel,40:60)' ;
%     bins55C55(nummodel,:) = [sum(A(1:5)),sum(A(6:10)),sum(A(11:15)),sum(A(16:20))]/sum(A(1:20)) ;
%     bins73C55(nummodel,:) = [sum(A(1:7))/7,sum(A(8:10))/3,sum(A(11:13))/3,sum(A(14:20))/7]/sum(A(1:20)) ;
% end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Firm Size Distribution %%%
%%% Plot for the paper     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

index_both = 1 ;
index_sunk = 2 ;
index_tax = 3 ;
index_none = 4 ;

vv = (40:59) ;
topsc = .4 ;


%%%
%%% unconditional + conditional (all ME)
%%%

binsUCdata = [9486
    7575
    8311
    7752
    7666
    8239
    7548
    7841
    8916
    9916
    4140
    3097
    3130
    3040
    2901
    2826
    2638
    2526
    2670
    2344] ;
binsUCdataK = binsUCdata ;
binsUCdata = binsUCdata/sum(binsUCdata) ;
binsCdata = [229
    257
    294
    300
    335
    387
    446
    458
    584
    721
    490
    471
    591
    677
    711
    841
    892
    867
    946
    819];
binsCdataK = binsCdata ;
binsCdata = binsCdata/sum(binsCdata) ;





disp('mean, med, std, var, skew, kurt: no ME')
disp(storebasics)
disp('mean, med, std, var, skew, kurt: with ME')
disp(storebasicsME)
% disp('bins 5-5')
% disp('bins with ME: 40-44,45-49,50-54,55-59')
% bins55U
% disp('Conditional 55 bins with ME: 40-44,45-49,50-54,55-59')
% bins55C55
disp('bins 7-3')
disp('bins with ME: 40-46,47-49,50-52,53-59')
bins73U
disp('Conditional 55 bins with ME: 40-46,47-49,50-52,53-59')
bins73C55


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Firm Size Distribution %%%
%%% UnConditional            %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for itt=1:2
    
    if itt==1
        topsc = .15 ;
    else
        topsc = .35 ;
    end
    
    figure ;
    subplot(5,2,1) ; bar(vv,binsUCdata,'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Data')
%     ylabel('Frequency','Fontsize',11)
    subplot(5,2,2) ; bar(vv,binsUCdata,'r'); axis tight ;
    axis([40 59 0 topsc])
    title('This column: with ME')
    subplot(5,2,3) ; bar(vv,store1(index_none,vv)/sum(store1(index_none,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Without regulation')
%     ylabel('Frequency','Fontsize',11)
    subplot(5,2,4) ; bar(vv,store1b(index_none,vv)/sum(store1b(index_none,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    % title('With measurement error','Fontsize',12)
    subplot(5,2,5) ; bar(vv,store1(index_sunk,vv)/sum(store1(index_sunk,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Sunk Cost')
%     ylabel('Frequency','Fontsize',11)
    subplot(5,2,6) ; bar(vv,store1b(index_sunk,vv)/sum(store1b(index_sunk,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    subplot(5,2,7) ; bar(vv,store1(index_tax,vv)/sum(store1(index_tax,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title(' Wage Tax')
        ylabel('Unconditional Distribution (Frequency)','Fontsize',12)
    subplot(5,2,8) ; bar(vv,store1b(index_tax,vv)/sum(store1b(index_tax,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    subplot(5,2,9) ; bar(vv,store1(index_both,vv)/sum(store1(index_both,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Sunk Cost + Wage Tax')
%     ylabel('Frequency','Fontsize',11)
    xlabel('Employment Distribution','Fontsize',11)
    subplot(5,2,10) ; bar(vv,store1b(index_both,vv)/sum(store1b(index_both,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    xlabel('Employment Distribution','Fontsize',11)
    if itt==1&&printeps==1
        print -depsc2 UnconditionalB.eps
    elseif itt==0&&printeps==0
        print -depsc2 Unconditional.eps
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Firm Size Distribution %%%
%%% Conditional            %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for itt=1:2
    
    if itt==1 %truncated or not...
        topsc = .15 ;
    else
        topsc = .4 ;
    end
    
    figure ;
    subplot(5,2,1) ; bar(vv,binsCdata,'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Data')
%     ylabel('Frequency','Fontsize',11)
    subplot(5,2,2) ; bar(vv,binsCdata,'r'); axis tight ;
    axis([40 59 0 topsc])
    title('This column: with ME')
    subplot(5,2,3) ; bar(vv,store2(index_none,vv)/sum(store2(index_none,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Without regulation')
%     ylabel('Frequency','Fontsize',11)
    subplot(5,2,4) ; bar(vv,store2b(index_none,vv)/sum(store2b(index_none,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    % title('With measurement error','Fontsize',12)
    subplot(5,2,5) ; bar(vv,store2(index_sunk,vv)/sum(store2(index_sunk,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Sunk cost')
%     ylabel('Frequency','Fontsize',11)
    subplot(5,2,6) ; bar(vv,store2b(index_sunk,vv)/sum(store2b(index_sunk,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    subplot(5,2,7) ; bar(vv,store2(index_tax,vv)/sum(store2(index_tax,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Wage Tax')
    ylabel('Conditional Distribution (Frequency)','Fontsize',12)
    subplot(5,2,8) ; bar(vv,store2b(index_tax,vv)/sum(store2b(index_tax,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    subplot(5,2,9) ; bar(vv,store2(index_both,vv)/sum(store2(index_both,vv)),'b'); axis tight ;
    axis([40 59 0 topsc])
    title('Sunk Cost + Wage Tax')
%     ylabel('Frequency','Fontsize',11)
    xlabel('Employment Conditional Distribution','Fontsize',11)
    subplot(5,2,10) ; bar(vv,store2b(index_both,vv)/sum(store2b(index_both,vv)),'r'); axis tight ;
    axis([40 59 0 topsc])
    xlabel('Employment Conditional Distribution','Fontsize',11)
    
    if itt==1&&printeps==1
        print -depsc2 ConditionalB.eps
    elseif itt==0&&printeps==1
        print -depsc2 Conditional.eps
    end
end
    

%%%%%%%%%%%%%%%%%%%%%%%%    
% figure of the paper %%
% but wo ME % 
%%%%%%%%%%%%%%%%%%%%%%%%

vv = (40:59) ;
axsc = .15 ;
axsc2 = .15 ;
figure ;
subplot(3,2,1) ;
plot(vv,binsUCdata,'k','LineWidth',2);
hold on ;
plot(vv,store1(index_sunk,vv)/sum(store1(index_sunk,vv)),'b-.','LineWidth',2);
hold on ;
axis([40 59 0 axsc])
title('Sunk cost','Fontsize',13)

subplot(3,2,2) ;
% plot(vv,binsCdata,'k','LineWidth',2);
plot(vv,binsCdata/sum(binsCdata),'k','LineWidth',2);
hold on ;
plot(vv,store2(index_sunk,vv)/sum(store2(index_sunk,vv)),'b-.','LineWidth',2);
% title('conditional','Fontsize',13)
axis([40 59 0 axsc2])
hold on ;

subplot(3,2,3) ;
% plot(vv,binsUCdata,'k','LineWidth',2);
plot(vv,binsUCdata,'k','LineWidth',2);
hold on ;
plot(vv,store1(index_tax,vv)/sum(store1(index_tax,vv)),'b-.','LineWidth',2);
hold on ;
title('Wage Tax','Fontsize',13)
axis([40 59 0 axsc])

subplot(3,2,4) ;
% plot(vv,binsCdata,'k','LineWidth',2);
plot(vv,binsCdata/sum(binsCdata),'k','LineWidth',2);
hold on ;
plot(vv,store2(index_tax,vv)/sum(store2(index_tax,vv)),'b-.','LineWidth',2);
% title('conditional','Fontsize',13)
axis([40 59 0 axsc2])
hold on ;

subplot(3,2,6) ;
plot(vv,binsCdata/sum(binsCdata),'k','LineWidth',2);
% plot(vv,binsCdata,'k','LineWidth',2);
hold on ;
plot(vv,store2(index_both,vv)/sum(store2(index_both,vv)),'b-.','LineWidth',2);
hold on ;
% title('conditional','Fontsize',13)
axis([40 59 0 axsc2])
xlabel('Conditional Distribution','Fontsize',13)

subplot(3,2,5) ;
% plot(vv,binsUCdata,'k','LineWidth',2);
plot(vv,binsUCdata,'k','LineWidth',2);
hold on ;
plot(vv,store1(index_both,vv)/sum(store1(index_both,vv)),'b-.','LineWidth',2);
hold on ;
title('Sunk Cost + Wage Tax','Fontsize',13)
xlabel('Unconditional Distribution','Fontsize',13)
axis([40 59 0 axsc])
    if printeps==1
print -depsc2 FitAllwoME.eps
    end


    
%%%%%%%%%%%%%%%%%%%%%%%%    
% figure of the paper %%
%%%%%%%%%%%%%%%%%%%%%%%%

vv = (40:59) ;
axsc = .15 ;
axsc2 = .15 ;
figure ;
subplot(3,2,1) ;
plot(vv,binsUCdata,'k','LineWidth',2);
hold on ;
plot(vv,store1b(index_sunk,vv)/sum(store1b(index_sunk,vv)),'b-.','LineWidth',2);
hold on ;
axis([40 59 0 axsc])
title('Sunk cost','Fontsize',13)

subplot(3,2,2) ;
% plot(vv,binsCdata,'k','LineWidth',2);
plot(vv,binsCdata/sum(binsCdata),'k','LineWidth',2);
hold on ;
plot(vv,store2b(index_sunk,vv)/sum(store2b(index_sunk,vv)),'b-.','LineWidth',2);
% title('conditional','Fontsize',13)
axis([40 59 0 axsc2])
hold on ;

subplot(3,2,3) ;
% plot(vv,binsUCdata,'k','LineWidth',2);
plot(vv,binsUCdata,'k','LineWidth',2);
hold on ;
plot(vv,store1b(index_tax,vv)/sum(store1b(index_tax,vv)),'b-.','LineWidth',2);
hold on ;
title('Wage Tax','Fontsize',13)
axis([40 59 0 axsc])

subplot(3,2,4) ;
% plot(vv,binsCdata,'k','LineWidth',2);
plot(vv,binsCdata/sum(binsCdata),'k','LineWidth',2);
hold on ;
plot(vv,store2b(index_tax,vv)/sum(store2b(index_tax,vv)),'b-.','LineWidth',2);
% title('conditional','Fontsize',13)
axis([40 59 0 axsc2])
hold on ;

subplot(3,2,6) ;
plot(vv,binsCdata/sum(binsCdata),'k','LineWidth',2);
% plot(vv,binsCdata,'k','LineWidth',2);
hold on ;
plot(vv,store2b(index_both,vv)/sum(store2b(index_both,vv)),'b-.','LineWidth',2);
hold on ;
% title('conditional','Fontsize',13)
axis([40 59 0 axsc2])
xlabel('Conditional Distribution','Fontsize',13)

subplot(3,2,5) ;
% plot(vv,binsUCdata,'k','LineWidth',2);
plot(vv,binsUCdata,'k','LineWidth',2);
hold on ;
plot(vv,store1b(index_both,vv)/sum(store1b(index_both,vv)),'b-.','LineWidth',2);
hold on ;
title('Sunk Cost + Wage Tax','Fontsize',13)
xlabel('Unconditional Distribution','Fontsize',13)
axis([40 59 0 axsc])
    if printeps==1
print -depsc2 FitAll.eps
end




if 0
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % stats in paper: firm size distribution %
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,2e2)/shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,5e2)/shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e3)/shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,5e3)/shareFirms(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    
    shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,2e2)/shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,5e2)/shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e3)/shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,5e3)/shareN(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0,1e2)
    
end