function [uz,oz,hz,beta1,beta2]=thresholds(alpha,nbar,wage,tau,lambda,r,cf,sigma,mu,sunkcost,z0)

% global prec prec2
%%%%%%%%%%%%%%
% Thresholds %
%%%%%%%%%%%%%%

uz = log( nbar^(1-alpha) * wage / alpha ) ;

%
% solve for oz \overline{z} using newton-raphson
%

oz          = uz*3/2 ; %initial value of oz
resid       = inf ;
ii          = 1 ;
tol         = 1e-12 ;
maxiter     = 200 ;
while ( abs(resid) > tol ) && ( ii < maxiter )
    resid     = foc_residual(oz,alpha,cf,lambda,mu,nbar,uz,0,r,sigma,sunkcost,tau,wage,1,0) ;
    resid_jac = foc_residual(oz,alpha,cf,lambda,mu,nbar,uz,0,r,sigma,sunkcost,tau,wage,1,1) ;
    oz        = oz - resid / resid_jac ;
    ii        = ii+1 ;
end
if ii==maxiter
    disp('problem w calc of thresholds oz')
end
%
% solve for hz \hat{z} using newton-raphson
%


if sunkcost==0
    
    hz = oz ;
    
else
    
    hz          = oz*2 ; %initial value not: hz=oz without sunk cost
    resid       = inf ;
    ii          = 1 ;
    tol         = 1e-11 ;
    maxiter     = 400 ;
    while ( abs(resid) > tol ) && ( ii < maxiter )
        resid     = foc_residual(hz,alpha,cf,lambda,mu,nbar,uz,oz,r,sigma,sunkcost,tau,wage,3,0) ;
        resid_jac = foc_residual(hz,alpha,cf,lambda,mu,nbar,uz,oz,r,sigma,sunkcost,tau,wage,3,1) ;
        hz        = hz - resid / resid_jac ;
        ii        = ii+1 ;
    end
    if ii==maxiter
        disp('problem w calc of thresholds hz')
    end
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% IVD
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

beta1   = ( mu.z - sqrt(mu.z^2 + 2 * lambda * sigma.z^2) ) / sigma.z^2 ;
beta2   = ( mu.z + sqrt(mu.z^2 + 2 * lambda * sigma.z^2) ) / sigma.z^2 ;

% [uz,oz,hz]
% beta1
% beta2

% K = (alpha/wage)^(alpha/(1-alpha)) ;
% K2 = (alpha/(wage*(1+tau.wage)))^(alpha/(1-alpha))*beta1*beta2/(beta1-beta2) ;
%
% part1n = K*exp(z0/(1-alpha))*(1-exp(beta1*(hz-z0))*exp(beta2*(-hz+z0)))/(beta2+1/(1-alpha)) ;
%
% part2n = K*exp(beta1*(hz-z0))*exp(uz/(1-alpha))*exp(beta2*(uz-hz))/(beta2+1/(1-alpha)) ;
%
% part3n = K*( (exp(uz/(1-alpha))*exp(beta1*(uz-z0))-exp(z0/(1-alpha)))/(beta1+1/(1-alpha)) + ...
%     -exp(beta1*(hz-z0))*(exp(beta2*(uz-oz))*exp(uz/(1-alpha))-exp(z0/(1-alpha))*exp(beta2*(z0-oz)))/(beta2+1/(1-alpha)));
%
% part4n = nbar^alpha*beta1*beta2/(beta1-beta2)*( (exp(beta1*(hz-z0))*exp(hz)-exp(uz)*exp(beta1*(uz-z0)))/(1+beta1) - exp(beta1*(hz-z0))*...
%     (exp(hz)-exp(uz)*exp(beta2*(uz-hz)))/(1+beta2) ) ;
%
% part5n = nbar^alpha*beta1*beta2/(beta1-beta2)*exp(beta1*(hz-z0))*( exp(oz+beta2*(oz-hz)) - exp(beta2*(uz-hz)+uz))/(1+beta2);
%
% part6n = K2*exp(beta1*(hz-z0))*(exp(hz/(1-alpha))-exp(oz/(1-alpha))*exp(beta2*(oz-hz)))/(1/(1-alpha)+beta2) ;
%
% part7n = -K2*exp(beta1*(hz-z0))*exp(hz/(1-alpha))/(1/(1-alpha)+beta1) ;
%
% totY = part1n + part2n + part3n + part4n + part5n + part6n + part7n ;